==> haskell-adjunctions-4.4-85-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.4
id: adjunctions-4.4-IPXV97ez6T3BNybUo3m1qr
key: adjunctions-4.4-IPXV97ez6T3BNybUo3m1qr
license: BSD-3-Clause
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors.
category: Data Structures, Adjunctions
abi: 0e657a09334d365aa6bf918dc124c250
exposed: True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
import-dirs: /usr/lib/ghc-8.6.5/site-local/adjunctions-4.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/adjunctions-4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/adjunctions-4.4
hs-libraries: HSadjunctions-4.4-IPXV97ez6T3BNybUo3m1qr
depends:
    array-0.5.3.0 base-4.12.0.0 comonad-5.0.5-Jl6mV4tCv8DH0upvqmXcGR
    containers-0.6.0.1 contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    distributive-0.6-GG50drgnUvrA8VTISpGDag
    free-5.1.1-2UBOpcP6tw37MFPUg5YXNd mtl-2.2.2
    profunctors-5.4-LjWaJA8kJzmIr0eJAafd3B
    semigroupoids-5.3.2-1VJu8li9guCCY6EpRRYm1V
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-adjunctions-4.4-87-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.4
id: adjunctions-4.4-IF422eX1oPa9TdjvcyX4Jq
key: adjunctions-4.4-IF422eX1oPa9TdjvcyX4Jq
license: BSD-3-Clause
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors.
category: Data Structures, Adjunctions
abi: b9c33a52e5a5c59f9a6030866ad47d31
exposed: True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
import-dirs: /usr/lib/ghc-8.6.5/site-local/adjunctions-4.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/adjunctions-4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/adjunctions-4.4
hs-libraries: HSadjunctions-4.4-IF422eX1oPa9TdjvcyX4Jq
depends:
    array-0.5.3.0 base-4.12.0.0 comonad-5.0.5-GxLjkJReVVVCdZ5ZrqdrbQ
    containers-0.6.0.1 contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    distributive-0.6-46i0ICRb7I89PMCNGFAS12
    free-5.1.1-2YsAmp8gnjAk9qd1XztnE mtl-2.2.2
    profunctors-5.4-Hkj445FiweuBattm2piECo
    semigroupoids-5.3.2-8PTnGnD8ohcIn54HVGc9tA
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
